Text Size - Medium Text Size - Large Text Size - Extra Large Text Size

# Fare Chart

Caltrain fares are based on the number of zones that are partially or wholly traveled through by the passenger. View the System Map HERE.

Full fares will apply to all customers 18 years of age or older except those who qualify for an Eligible Discount ticket, which is approximately 50 percent of the full-fare price. View the fare descriptions HERE.

Adult Full Fare
Ticket Type* | How to Buy | Travel within
1 Zone | 2 Zones | 3 Zones | 4 Zones | 5 Zones | 6 Zones
One Way | TVM | $3.00 | $5.00 | $7.00 | $9.00 | $11.00 | $13.00
Clipper Card | $2.75 | $4.75 | $6.75 | $8.75 | $10.75 | $12.75
Day Pass+ | TVM | $6.00 | $10.00 | $14.00 | $18.00 | $22.00 | $26.00
Zone Upgrade | TVM | $2.00
8-ride | Clipper Card | $20.25 | $35.25 | $50.00 | $64.75 | $79.50 | $94.25
Monthly Pass | Clipper Card | $73.00 | $126.00 | $179.00 | $232.00 | $285.00 | $338.00

TVM - Ticket Vending Machine
*Ticket Type definitions:
One-way: Valid 4 hours from time of purchase.
Day Pass: Valid the date of purchase, unlimited travel within zones indicated.
Zone Upgrade: Valid 4 hours from time of purchase, one way when accompanying another valid ticket (not valid with 8-ride Ticket).
8-ride: Valid 30 days from date of purchase.
Monthly Pass: Valid month of purchase.
For detailed Ticket Type information, click HERE.
+ With the opening of Levi’s® Stadium, Caltrain is offering a joint adult Caltrain/VTA Day Pass. The Caltrain portion is valid to Zone 3 and costs an additional $6 compared to a Caltrain Day Pass. The joint pass is valid on Caltrain through the last train of the night and on VTA buses and light rail until 3 a.m.
View the System Map HERE

Eligible Discount Fare**
Ticket Type* | How to Buy | Travel within
1 Zone | 2 Zones | 3 Zones | 4 Zones | 5 Zones | 6 Zones
One Way | TVM | $1.50 | $2.50 | $3.50 | $4.50 | $5.50 | $6.50
Clipper Card | $1.25 | $2.25 | $3.25 | $4.25 | $5.25 | $6.25
Day Pass | TVM | $3.00 | $5.00 | $7.00 | $9.00 | $11.00 | $13.00
Zone Upgrade | TVM | $1.00
8-ride | Clipper Card | $10.00 | $17.50 | $25.00 | $32.25 | $39.75 | $47.00
Monthly Pass | Clipper Card | $36.50 | $63.00 | $89.50 | $116.00 | $142.50 | $169.00

** Senior / Disabled / Youth / Medicare Cardholder. Conductor or fare inspector may request proof of age or eligibility.

## Subscribe

You can now receive Caltrain notifications via e-mail!
Find out more HERE

## Highlights

- Weekday Timetable
- Weekend Timetable
- Special Events
- Mobile Device Schedules
- Electrification

## Social